#
# spec file for package quiterss
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           quiterss
Version:        0.19.4
Release:        lp152.1.2
Summary:        RSS/Atom aggregator
License:        GPL-3.0-or-later
URL:            https://www.quiterss.org
Source:         https://quiterss.org/files/%{version}_/QuiteRSS-%{version}-src.tar.gz
Source99:       %{name}-rpmlintrc
# PATCH-FIX-UPSTREAM quiterss-fix_webkit.patch aloisio@gmx.com -- fixes build with qt5webkit < 5.212~alpha4
Patch0:         quiterss-fix_webkit.patch
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libqt5-linguist
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5WebKitWidgets)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(sqlite3)
Requires:       libQt5Sql5-sqlite
Recommends:     %{name}-lang = %{version}

%description
QuiteRSS is a RSS/Atom news feed reader.

%lang_package

%prep
%setup -q -c
%patch0 -p1
dos2unix AUTHORS CHANGELOG README.md

%build
%qmake5 PREFIX=%{_prefix}
%make_jobs

%install
%qmake5_install
%find_lang %{name} --with-qt --without-mo
%suse_update_desktop_file %{name}
%fdupes %{buildroot}

%files
%doc AUTHORS CHANGELOG README.md
%license COPYING
%dir %{_datadir}/%{name}
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/%{name}/sound
%{_datadir}/%{name}/style

%files lang -f %{name}.lang
%dir %{_datadir}/%{name}/lang

%changelog
* Tue Apr 21 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.19.4
  * Added: Share. Viber, Telegram
  * Added: Support Media-RSS
  * Added: Switch focus from search when pressing Esc
  * Changed: Lock headline news while scrolling content
  * Changed: Hide directories when searching in feeds
  * Fixed: Some news links do not have a scheme ("http")
  * Fixed: Dark App Style. Setting background color and text
    color for labels
  * Fixed: Dark App Style. Setting background color of
    alternative rows
  * Fixed: Updating some feeds
  * Fixed: Collapse of news description
- Added quiterss-fix_webkit.patch
* Thu Jan 30 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.19.3
  * Changed: App style: dark
  * Fixed: Application crash (Linux)
- Dropped group tag
* Tue Nov 26 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.19.2
  * Added: App style: dark
  * Fixed: Images are not displayed in some feeds
  * Fixed: Sometimes news filter did not work when updating feeds
* Sun Nov 17 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.19.1
  * Fixed: Parsing of some feeds
* Thu Nov 14 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.19.0
  * Main: Switch to Qt 5.13
  * Main: Embedded browser - WebKit 602.1
  * Added: Calendar to avoid downloading old new
  * Changed: SQLite 3.30.1
  * Removed: Share. Google+
  * Fixed: Description of some feeds
  * Fixed: Parsing of some feeds
* Mon Jul  2 2018 aloisio@gmx.com
- Update to version 0.18.12
  * Added: Share. Hacker News
  * Changed: Support for Qt 5.11 (Linux)
  * Changed: High DPI support
  * Fixed: Downloading feeds' icons for some feeds
* Thu May 31 2018 aloisio@gmx.com
- Update to version 0.18.11
  * Added: Notifications. Option "Close notification after opening
    news"
  * Added: Support for Youtube feeds
  * Changed: Folder property. Option "RTL" for all feeds in folder
* Tue Apr 17 2018 aloisio@gmx.com
- Update to version 0.18.10
  * Added: Shortcut "Search Feed"
  * Added: Page Up/Down in feeds tree
  * Changed: SQLite 3.23.0
  * Changed: Closing notification window when clicking on news
    header
  * Fixed: Splash screen always displayed (Linux)
  * Fixed: Parsing of some feeds (Accept-Language)
  * Fixed: Displaying dialogs in mode "Stay On Top"
  * Fixed: Go to next/previous unread news
* Fri Dec  1 2017 aloisio@gmx.com
- Update to version 0.18.9
  * Changed: SQLite 3.21.0
  * Changed: Displaying news is no more than width of window
  * Fixed: Parsing of some feeds (RDF)
  * Fixed: Resetting news list columns when switching between
    feeds
* Sun Nov 12 2017 aloisio@gmx.com
- Add explicit requirement for libQt5Sql5-sqlite
  (fixes boo#1067772)
- Added quiterss-rpmlintrc
* Thu Aug 24 2017 aloisio@gmx.com
- Update to version 0.18.8
  * Fixed: "Show Unread" news filter was not working
* Wed Aug 23 2017 aloisio@gmx.com
- Update to version 0.18.7
  * Added: Share. Reddit, Instapaper
  * Changed: SQLite 3.20.0
  * Changed: Displaying icon in system tray
  * Fixed: Copying folder properties when adding feed
  * Fixed: Duplicated news without headings
  * Fixed: Share. Email (Linux)
  * Fixed: Application crash when open browser tab and layout
    switching
  * Fixed: Sometimes regular expressions in filters did not work
  * Fixed: Some content links of the news description has no
    "http" schema
- Dropped quiterss-list_qmfiles.patch (fixed upstream)
* Wed Jun 21 2017 aloisio@gmx.com
- Update to version 0.18.6
  * Changed: SQLite 3.19.3
  * Fixed: Displaying dialogs in mode "Stay on top"
  * Fixed: Mark displayed news as read when switching feeds
* Fri Jun 16 2017 aloisio@gmx.com
- Update to version 0.18.5
  * Changed: SQLite 3.19.1
  * Changed: Application icon size
  * Fixed: Parsing of some feeds
  * Fixed: Switching between feeds in Newspaper view
  * Fixed: Layout in Newspaper view
  * Fixed: Notification. Displaying of previous news
- Dropped quiterss-fix-tray-icon.patch (merged upstream)
- Reverted previous change and replaced it with
  quiterss-list_qmfiles.patch
- Set proper QMAKE_LRELEASE executable
* Thu Jun 15 2017 alarrosa@suse.com
- Fix build failing due to wrong reference to language files.
  They were referenced with a wildcard in the qmake file, but the
  files were not yet generated when qmake was run.
* Sun Feb  5 2017 jengelh@inai.de
- Trim filler words from description
* Wed Dec  7 2016 aloisio@gmx.com
- Added quiterss-fix-tray-icon.patch (fixes tray icon size)
* Sat Dec  3 2016 aloisio@gmx.com
- Switched to qt5
- Spec cleanup
* Tue Jan 24 2012 ti.eugene@gmail.com
- Initial build
